/*
 * Copyright 2003-2007 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.codehaus.groovy.tools.groovydoc;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;
import org.codehaus.groovy.runtime.DefaultGroovyMethods;

public class ClasspathResourceManager implements ResourceManager {
	ClassLoader classLoader;
	public ClasspathResourceManager() {
		classLoader = getClass().getClassLoader();
	}
	
	public ClasspathResourceManager(ClassLoader classLoader) {
		this.classLoader = classLoader;
	}

	public InputStream getInputStream(String resourceName) throws IOException {
        return classLoader.getResourceAsStream(resourceName);
	}

	public Reader getReader(String resourceName) throws IOException {
        return DefaultGroovyMethods.newReader(getInputStream(resourceName));
	}

}
